<?php
/*
  Plugin Name: Easy Lightbox
  Author URI: http://savvaswppremium.weebly.com
  Description: With the Easy Lightbox you can Add custom lightbox attribute to linked flash files or images in posts, pages and comments, group images using ID. 
  Version: 1.0
  Author: Mesut Savvas
  License: GPLv3 or later
*/

/*  Copyright 2012 - 2013 Mesut Savvas  (email : yilmassavvas@yahoo.com)

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

//create options page
add_action( 'admin_menu', 'easylightbox_menu' );
function easylightbox_menu() {
  add_options_page( 'Easy Lightbox', 'Easy Lightbox', 'manage_options', 'easylightbox-options', 'easylightbox_settings' );
  add_action( 'admin_init', 'register_easylightbox_settings' );
}

//register settings
function register_easylightbox_settings(){
  register_setting( 'easylightbox_settings_group', 'easylightbox' );
  register_setting( 'easylightbox_settings_group', 'easylightbox_flash' );

//setting page
function easylightbox_settings() {
?>
<div class="wrap">
  <h2>Easy Lightbox</h2>
  <form method="post" action="options.php">
    <?php
	  settings_fields( 'easylightbox_settings_group' );
	  do_settings_sections( 'easylightbox_settings_group' );
	  $easylightbox_code = htmlspecialchars( get_option( 'easylightbox' ), ENT_QUOTES );
	  $easylightbox_flash_code = htmlspecialchars( get_option( 'easylightbox_flash' ), ENT_QUOTES );
	  $plugin_dir = basename(dirname(__FILE__));
	  load_plugin_textdomain( 'easylightbox', false, $plugin_dir );
	?>
	<p><?php _e( 'Input lightbox attributes below (both optional), for example <em>rel=&quot;lightbox&quot;</em>, <em>class=&quot;colorbox&quot;</em>.', 'easylightbox' ) ?></p>
	<p><?php _e( 'To group images by ID use <strong>[id]</strong> for example <em>rel=&quot;prettyPhoto[id]&quot;</em>.', 'easylightbox' ) ?></p>
	<p><strong style="float:left;display:block;width:45px;text-align:right;margin:3px 6px 0 0;">Images:</strong> <input type="text" style="width:200px;" name="easylightbox" value="<?php echo $easylightbox_code; ?>" /></p>
	<p><strong style="float:left;display:block;width:45px;text-align:right;margin:3px 6px 0 0;">Flash:</strong> <input type="text" style="width:200px;" name="easylightbox_flash" value="<?php echo $easylightbox_flash_code; ?>" /></p>
    <p class="submit">
    <input type="submit" class="button-primary" value="<?php _e('Save Changes') ?>" />
    </p>
</form>
</div>
<?php }
//uninstall hook
if ( function_exists('register_uninstall_hook') )
    register_uninstall_hook(__FILE__, 'easylightbox_uninstall_hook');
function easylightbox_uninstall_hook() {
  delete_option('easylightbox');
  delete_option('easylightbox_flash');
}
//the replace functions
function easylightbox_replace( $content ) {
  global $post;
  $addpostid = '[' .$post->ID. ']';
  $easylightbox_replacement = preg_replace( '/\[(id)\]/', $addpostid, get_option( 'easylightbox' ) );
  $replacement = '<a$1href=$2$3.$4$5 ' .$easylightbox_replacement. '$6>$7</a>';
  $content = preg_replace( '/<a(.*?)href=(\'|")([^>]*).(bmp|gif|jpeg|jpg|png)(\'|")(.*?)>(.*?)<\/a>/i', $replacement, $content );
  return $content;
}
function easylightbox_flash_replace( $content ) {
  global $post;
  $addpostid = '[' .$post->ID. ']';
  $easylightbox_flash_replacement = preg_replace( '/\[(id)\]/', $addpostid, get_option( 'easylightbox_flash' ) );
  $replacement = '<a$1href=$2$3.$4$5 '.$easylightbox_flash_replacement.'$6>$7</a>';
  $content = preg_replace( '/<a(.*?)href=(\'|")([^>]*).(swf|flv)(\'|")(.*?)>(.*?)<\/a>/i', $replacement, $content );
  return $content;
}
//if options set add filters
if ( get_option( 'easylightbox' ) != null) {
  add_filter( 'the_content', 'easylightbox_replace', 12 );
  add_filter( 'get_comment_text', 'easylightbox_replace', 12 );
}
if ( get_option( 'easylightbox_flash' ) != null) {
  add_filter( 'the_content', 'easylightbox_flash_replace', 13 );
  add_filter( 'get_comment_text', 'easylightbox_flash_replace', 13 );
}
?>